@@ -168,6 +168,7 @@ types: list[str] = [
     "AWS::CUR::ReportDefinition",
     "AWS::Cassandra::Keyspace",
     "AWS::Cassandra::Table",
+    "AWS::Cassandra::Type",
     "AWS::CertificateManager::Account",
     "AWS::CertificateManager::Certificate",
     "AWS::Chatbot::CustomAction",
@@ -201,6 +202,7 @@ types: list[str] = [
     "AWS::CloudFormation::TypeActivation",
     "AWS::CloudFormation::WaitCondition",
     "AWS::CloudFormation::WaitConditionHandle",
+    "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
@@ -215,6 +217,7 @@ types: list[str] = [
     "AWS::CloudFront::RealtimeLogConfig",
     "AWS::CloudFront::ResponseHeadersPolicy",
     "AWS::CloudFront::StreamingDistribution",
+    "AWS::CloudFront::VpcOrigin",
     "AWS::CloudTrail::Channel",
     "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
@@ -279,6 +282,7 @@ types: list[str] = [
     "AWS::Connect::ApprovedOrigin",
     "AWS::Connect::ContactFlow",
     "AWS::Connect::ContactFlowModule",
+    "AWS::Connect::ContactFlowVersion",
     "AWS::Connect::EmailAddress",
     "AWS::Connect::EvaluationForm",
     "AWS::Connect::HoursOfOperation",
@@ -309,6 +313,7 @@ types: list[str] = [
     "AWS::CustomerProfiles::CalculatedAttributeDefinition",
     "AWS::CustomerProfiles::Domain",
     "AWS::CustomerProfiles::EventStream",
+    "AWS::CustomerProfiles::EventTrigger",
     "AWS::CustomerProfiles::Integration",
     "AWS::CustomerProfiles::ObjectType",
     "AWS::CustomerProfiles::SegmentDefinition",
@@ -362,11 +367,13 @@ types: list[str] = [
     "AWS::Deadline::Farm",
     "AWS::Deadline::Fleet",
     "AWS::Deadline::LicenseEndpoint",
+    "AWS::Deadline::Limit",
     "AWS::Deadline::MeteredProduct",
     "AWS::Deadline::Monitor",
     "AWS::Deadline::Queue",
     "AWS::Deadline::QueueEnvironment",
     "AWS::Deadline::QueueFleetAssociation",
+    "AWS::Deadline::QueueLimitAssociation",
     "AWS::Deadline::StorageProfile",
     "AWS::Detective::Graph",
     "AWS::Detective::MemberInvitation",
@@ -690,9 +697,6 @@ types: list[str] = [
     "AWS::InspectorV2::Filter",
     "AWS::InternetMonitor::Monitor",
     "AWS::Invoicing::InvoiceUnit",
-    "AWS::IoT1Click::Device",
-    "AWS::IoT1Click::Placement",
-    "AWS::IoT1Click::Project",
     "AWS::IoT::AccountAuditConfiguration",
     "AWS::IoT::Authorizer",
     "AWS::IoT::BillingGroup",
@@ -944,6 +948,13 @@ types: list[str] = [
     "AWS::NimbleStudio::StreamingImage",
     "AWS::NimbleStudio::Studio",
     "AWS::NimbleStudio::StudioComponent",
+    "AWS::Notifications::ChannelAssociation",
+    "AWS::Notifications::EventRule",
+    "AWS::Notifications::ManagedNotificationAccountContactAssociation",
+    "AWS::Notifications::ManagedNotificationAdditionalChannelAssociation",
+    "AWS::Notifications::NotificationConfiguration",
+    "AWS::Notifications::NotificationHub",
+    "AWS::NotificationsContacts::EmailContact",
     "AWS::OSIS::Pipeline",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
@@ -981,6 +992,9 @@ types: list[str] = [
     "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
     "AWS::PCAConnectorSCEP::Challenge",
     "AWS::PCAConnectorSCEP::Connector",
+    "AWS::PCS::Cluster",
+    "AWS::PCS::ComputeNodeGroup",
+    "AWS::PCS::Queue",
     "AWS::Panorama::ApplicationInstance",
     "AWS::Panorama::Package",
     "AWS::Panorama::PackageVersion",
@@ -1028,6 +1042,7 @@ types: list[str] = [
     "AWS::QLDB::Ledger",
     "AWS::QLDB::Stream",
     "AWS::QuickSight::Analysis",
+    "AWS::QuickSight::CustomPermissions",
     "AWS::QuickSight::Dashboard",
     "AWS::QuickSight::DataSet",
     "AWS::QuickSight::DataSource",
@@ -1214,6 +1229,7 @@ types: list[str] = [
     "AWS::SageMaker::MonitoringSchedule",
     "AWS::SageMaker::NotebookInstance",
     "AWS::SageMaker::NotebookInstanceLifecycleConfig",
+    "AWS::SageMaker::PartnerApp",
     "AWS::SageMaker::Pipeline",
     "AWS::SageMaker::Project",
     "AWS::SageMaker::Space",
@@ -1293,6 +1309,7 @@ types: list[str] = [
     "AWS::Transfer::Profile",
     "AWS::Transfer::Server",
     "AWS::Transfer::User",
+    "AWS::Transfer::WebApp",
     "AWS::Transfer::Workflow",
     "AWS::VerifiedPermissions::IdentitySource",
     "AWS::VerifiedPermissions::Policy",
